﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class GameManager : MonoBehaviour {

	public static GameManager instance;

	public Baby babyPrefab;
	public Whale whalePrefab;

	public Transform babySpawnPoint;

	public Transform babiesParent;

	public List<Baby> babies;
	public List<Whale> whales;

	public int maxLife = 3;
	public int life = 3;
	public int player1Score = 0;
	public int player2Score = 0;
	public float babyRate = 5f;

	private bool onePlayer = false;

	private bool isPlaying = false;

	private float lastBabyAdded = 0;

	void Awake () {
		instance = this;
	}

	void Update()
	{
		if (isPlaying && Time.time > lastBabyAdded + babyRate)
		{
			AddBaby();
		}
	}

	public void PlayGame(bool _onePlayer)
	{
		onePlayer = _onePlayer;
		foreach (Whale whale in whales)
		{
			whale.ResetWave();
		}
		life=maxLife;
		player1Score=0;
		player2Score=0;
		MainUIManager.instance.inGameMenu.player1Score.text = player1Score.ToString();
		MainUIManager.instance.inGameMenu.player2Score.text = player2Score.ToString();
		MainUIManager.instance.inGameMenu.lifes.text = life.ToString();
		MainUIManager.instance.inGameMenu.player2Score.gameObject.SetActive(!onePlayer);
		isPlaying = true;
		AddBaby();
	}

	public void EndGame()
	{
		for(int i = babiesParent.childCount-1; i>=0; i--)
		{
			Destroy(babiesParent.GetChild(i).gameObject);
		}
		babies.Clear();
		isPlaying = false;
		MainUIManager.instance.endGameMenu.player1Score.text = player1Score.ToString();
		MainUIManager.instance.endGameMenu.player2Score.text = player2Score.ToString();
		MainUIManager.instance.endGameMenu.player2Score.gameObject.SetActive(!onePlayer);
		MainUIManager.instance.inGameMenu.OpenEndGameMenu();
	}

	public void DecreaseLife(Baby baby)
	{
		if (isPlaying)
		{
			babies.Remove(baby);
			life--;
			MainUIManager.instance.inGameMenu.lifes.text = life.ToString();
			if (life <= 0)
			{
				EndGame();
			}
			else if (babies.Count == 0)
			{
				AddBaby();
			}
		}
	}

	private void AddBaby()
	{
		lastBabyAdded = Time.time;
		var clone = Instantiate (babyPrefab, babySpawnPoint.position, Quaternion.identity, babiesParent) as Baby;
		babies.Add(clone);
	}

	public void AddScore(KeyCode whaleKey)
	{
		if (onePlayer)
		{
			player1Score++;
			MainUIManager.instance.inGameMenu.player1Score.text = player1Score.ToString();
		}
		else
		{
			switch(whaleKey)
			{
			case KeyCode.Alpha1:
			case KeyCode.Alpha2:
			case KeyCode.Alpha3:
			case KeyCode.Alpha4:
			case KeyCode.Alpha5:
				player1Score++;
				MainUIManager.instance.inGameMenu.player1Score.text = player1Score.ToString();
				break;
			case KeyCode.Alpha6:
			case KeyCode.Alpha7:
			case KeyCode.Alpha8:
			case KeyCode.Alpha9:
			case KeyCode.Alpha0:
				player2Score++;
				MainUIManager.instance.inGameMenu.player2Score.text = player2Score.ToString();
				break;
			}
		}
	}
}
