﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Whale : MonoBehaviour {

	public enum WaveDirection
	{
		UP,
		DOWN,
		STAY_UP,
		STAY_DOWN
	}

	public float waveUpTimeLength = 1f;
	public float waveStayUpTimeLength = 1f;
	public float waveDownTimeLength = 1f;
	public float waveMaxLength = 1f;

	private float waveLength = 0f;

	public KeyCode waveKey = KeyCode.Alpha1;

	public Transform waveTransform;
	public Transform waveColliderTransform;
	public Animator whaleAnimator;

	public AudioClip[] splash;

	private float index=0;
	private float upRate;
	private float stayUpRate;
	private float downRate;

	private bool isKeyPress = false;

	private WaveDirection waveDirection = WaveDirection.STAY_DOWN;

	// Use this for initialization
	void Start () {
		upRate=1.0f/waveUpTimeLength;
		stayUpRate=1.0f/waveStayUpTimeLength;
		downRate=1.0f/waveDownTimeLength;
		SetVisualWaveSize();
		whaleAnimator.Play("whale", 0, Random.Range(0f, 1f));
	}
	
	// Update is called once per frame
	void Update () {
		if (Input.GetKeyDown (waveKey) )
		{
			StartWave();
		}
		if (Input.GetKeyUp (waveKey) )
		{
			EndWave();
		}
		CalculateWave ();
	}

	void CalculateWave ()
	{
		switch (waveDirection)
		{
		case WaveDirection.UP:
			if(index<1.0f)
			{
				waveLength = Mathf.Lerp(0f, waveMaxLength, index);
				index+=upRate*Time.deltaTime;
			}else{
				waveLength = waveMaxLength;
				index=0f;
				if (isKeyPress)
				{
					waveDirection = WaveDirection.STAY_UP;
				}
				else
				{
					waveDirection = WaveDirection.DOWN;
				}
			}
			SetVisualWaveSize();
			break;
		case WaveDirection.DOWN:
			if(index<1.0f)
			{
				waveLength = Mathf.Lerp(0f, waveMaxLength, 1f-index);
				index+=downRate*Time.deltaTime;
			}else{
				waveLength = 0f;
				index=0f;
				waveDirection = WaveDirection.STAY_DOWN;
			}
			SetVisualWaveSize();
			break;
		case WaveDirection.STAY_UP:
			if(index<1.0f)
			{
				waveLength = waveMaxLength;
				index+=stayUpRate*Time.deltaTime;
				if (!isKeyPress)
				{
					index=0f;
					waveDirection = WaveDirection.DOWN;
				}
			}else{
				waveLength = waveMaxLength;
				index=0f;
				waveDirection = WaveDirection.DOWN;
			}
			SetVisualWaveSize();
			break;
		}
	}

	private void SetVisualWaveSize()
	{
		waveTransform.localScale = new Vector3 (Mathf.Clamp(waveLength, 0.1f, waveMaxLength), Mathf.Clamp(waveLength * 2f, 0.1f, waveMaxLength * 2f), Mathf.Clamp(waveLength, 0.1f, waveMaxLength));
		waveColliderTransform.localPosition = new Vector3 (0f, waveLength * 2f, 0f);
	}

	public void StartWave()
	{
		if (waveDirection == WaveDirection.DOWN
			|| waveDirection == WaveDirection.STAY_DOWN)
		{
			if (waveDirection == WaveDirection.DOWN)
			{
				index = 1f-index;
			}
			else
			{
				SoundManager.PlaySFX(splash[Random.Range(0,splash.Length)], 0.2f);
			}
			waveDirection = WaveDirection.UP;
			isKeyPress = true;
		}
	}

	public void EndWave()
	{
		isKeyPress = false;
	}

	public void ResetWave()
	{
		isKeyPress = false;
		index=0f;
		waveDirection = WaveDirection.STAY_DOWN;
		SetVisualWaveSize();
	}
}
